==> javascriptstuff-db-1.10.2.tgz: package/view-libraries.js <==
module.exports = {
  "key": "view-libraries",
  "name": "View Libraries",
  "description": "View libraries render your app in the browser. You provide some code or data in a format that is specific to the library, and the library handles rendering DOM elements and styles. All of these run within the browser, but some also run on the server.",
  "aka": [
    "UX Libraries",
    "UX Frameworks"
  ],
  "tags": [
    {
      "name": "mobile",
      "description": "Renders native views on iOS/Android instead of browser DOM elements."
    }
  ],
  "articles": [],
  "projects": [
    {
      "githubPath": "hyperapp/hyperapp",
      "description": "1 KB JavaScript library for building web applications.",
      "homepage": "https://hyperapp.js.org",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 11017,
      "lastUpdatedAt": "2018-02-15T16:31:15Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/25238911?v=4"
    },
    {
      "githubPath": "facebook/react",
      "description": "A declarative, efficient, and flexible JavaScript library for building user interfaces.",
      "homepage": "https://reactjs.org",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 88423,
      "lastUpdatedAt": "2018-02-15T15:12:36Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/69631?v=4"
    },
    {
      "githubPath": "developit/preact",
      "description": "⚛️ Fast 3kB React alternative with the same modern API. Components & Virtual DOM.",
      "homepage": "https://preactjs.com",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 17681,
      "lastUpdatedAt": "2018-02-15T15:52:05Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/105127?v=4"
    },
    {
      "githubPath": "angular/angular",
      "description": "One framework. Mobile & desktop.",
      "homepage": "https://angular.io",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 33090,
      "lastUpdatedAt": "2018-02-15T15:59:36Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/139426?v=4"
    },
    {
      "githubPath": "MithrilJS/mithril.js",
      "description": "A Javascript Framework for Building Brilliant Applications",
      "homepage": "http://mithril.js.org",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 8389,
      "lastUpdatedAt": "2018-02-15T15:38:18Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/19475707?v=4"
    },
    {
      "githubPath": "elm-lang/elm-compiler",
      "description": "Compiler for Elm, a functional language for reliable webapps.",
      "homepage": "http://elm-lang.org/",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 4373,
      "lastUpdatedAt": "2018-02-15T15:18:32Z",
      "avatarUrl": "https://avatars0.githubusercontent.com/u/4359353?v=4"
    },
    {
      "githubPath": "facebook/react-native",
      "description": "A framework for building native apps with React.",
      "homepage": "http://facebook.github.io/react-native/",
      "dependencies": null,
      "tags": [
        "mobile"
      ],
      "lastStarCount": 59823,
      "lastUpdatedAt": "2018-02-15T16:39:56Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/69631?v=4"
    },
    {
      "githubPath": "OnsenUI/OnsenUI",
      "description": "Mobile app development framework and SDK using HTML5 and JavaScript. Create beautiful and performant cross-platform mobile apps. Based on Web Components, and provides bindings for Angular 1, 2, React and Vue.js.",
      "homepage": "https://onsen.io/",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 6022,
      "lastUpdatedAt": "2018-02-15T10:08:18Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/5972822?v=4"
    },
    {
      "githubPath": "emberjs/ember.js",
      "description": "Ember.js - A JavaScript framework for creating ambitious web applications",
      "homepage": "http://www.emberjs.com",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 18733,
      "lastUpdatedAt": "2018-02-15T16:16:47Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/1253363?v=4"
    },
    {
      "githubPath": "vuejs/vue",
      "description": "🖖 A progressive, incrementally-adoptable JavaScript framework for building UI on the web.",
      "homepage": "http://vuejs.org",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 83840,
      "lastUpdatedAt": "2018-02-15T16:29:47Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/6128107?v=4"
    },
    {
      "githubPath": "NativeScript/NativeScript",
      "description": "NativeScript is an open source framework for building truly native mobile apps with JavaScript. Use web skills, like Angular, FlexBox and CSS, and get native UI and performance on iOS and Android.",
      "homepage": "http://www.nativescript.org",
      "dependencies": null,
      "tags": [
        "mobile"
      ],
      "lastStarCount": 12455,
      "lastUpdatedAt": "2018-02-15T09:40:25Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/7392261?v=4"
    }
  ]
}

==> javascriptstuff-db-1.11.0.tgz: package/view-libraries.js <==
module.exports = {
  "key": "view-libraries",
  "name": "View Libraries",
  "description": "View libraries render your app in the browser. You provide some code or data in a format that is specific to the library, and the library handles rendering DOM elements and styles. All of these run within the browser, but some also run on the server.",
  "aka": [
    "UX Libraries",
    "UX Frameworks"
  ],
  "tags": [
    {
      "name": "mobile",
      "description": "Renders native views on iOS/Android instead of browser DOM elements."
    }
  ],
  "articles": [],
  "projects": [
    {
      "githubPath": "hyperapp/hyperapp",
      "description": "1 kB JavaScript framework for building web applications.",
      "homepage": "https://hyperapp.js.org",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 12092,
      "lastUpdatedAt": "2018-04-13T17:04:17Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/25238911?v=4"
    },
    {
      "githubPath": "facebook/react",
      "description": "A declarative, efficient, and flexible JavaScript library for building user interfaces.",
      "homepage": "https://reactjs.org",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 93415,
      "lastUpdatedAt": "2018-04-13T20:01:44Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/69631?v=4"
    },
    {
      "githubPath": "developit/preact",
      "description": "⚛️ Fast 3kB React alternative with the same modern API. Components & Virtual DOM.",
      "homepage": "https://preactjs.com",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 18388,
      "lastUpdatedAt": "2018-04-13T17:25:21Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/105127?v=4"
    },
    {
      "githubPath": "angular/angular",
      "description": "One framework. Mobile & desktop.",
      "homepage": "https://angular.io",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 35038,
      "lastUpdatedAt": "2018-04-13T20:14:44Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/139426?v=4"
    },
    {
      "githubPath": "MithrilJS/mithril.js",
      "description": "A Javascript Framework for Building Brilliant Applications",
      "homepage": "http://mithril.js.org",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 8521,
      "lastUpdatedAt": "2018-04-13T14:59:29Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/19475707?v=4"
    },
    {
      "githubPath": "elm-lang/elm-compiler",
      "description": "Compiler for Elm, a functional language for reliable webapps.",
      "homepage": "http://elm-lang.org/",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 4465,
      "lastUpdatedAt": "2018-04-13T17:23:04Z",
      "avatarUrl": "https://avatars0.githubusercontent.com/u/4359353?v=4"
    },
    {
      "githubPath": "facebook/react-native",
      "description": "A framework for building native apps with React.",
      "homepage": "http://facebook.github.io/react-native/",
      "dependencies": null,
      "tags": [
        "mobile"
      ],
      "lastStarCount": 62523,
      "lastUpdatedAt": "2018-04-13T20:12:50Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/69631?v=4"
    },
    {
      "githubPath": "OnsenUI/OnsenUI",
      "description": "Mobile app development framework and SDK using HTML5 and JavaScript. Create beautiful and performant cross-platform mobile apps. Based on Web Components, and provides bindings for Angular 1, 2, React and Vue.js.",
      "homepage": "https://onsen.io/",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 6237,
      "lastUpdatedAt": "2018-04-13T20:00:58Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/5972822?v=4"
    },
    {
      "githubPath": "emberjs/ember.js",
      "description": "Ember.js - A JavaScript framework for creating ambitious web applications",
      "homepage": "http://www.emberjs.com",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 18897,
      "lastUpdatedAt": "2018-04-13T19:16:58Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/1253363?v=4"
    },
    {
      "githubPath": "vuejs/vue",
      "description": "🖖 A progressive, incrementally-adoptable JavaScript framework for building UI on the web.",
      "homepage": "http://vuejs.org",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 90645,
      "lastUpdatedAt": "2018-04-13T20:01:48Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/6128107?v=4"
    },
    {
      "githubPath": "NativeScript/NativeScript",
      "description": "NativeScript is an open source framework for building truly native mobile apps with JavaScript. Use web skills, like Angular, FlexBox and CSS, and get native UI and performance on iOS and Android.",
      "homepage": "http://www.nativescript.org",
      "dependencies": null,
      "tags": [
        "mobile"
      ],
      "lastStarCount": 13151,
      "lastUpdatedAt": "2018-04-13T20:14:26Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/7392261?v=4"
    }
  ]
}
